@@ -46,10 +46,6 @@
 #' It would be wise to use some negative and positive control comparisons
 #' where relevant to help guide interpretation of the results.
 #'
-#' @keywords extract APseAAC APAAC Amphiphilic Composition
-#'
-#' @aliases extractAPAAC
-#'
 #' @author Nan Xiao <\url{https://nanx.me}>
 #'
 #' @seealso See \code{\link{extractPAAC}} for the
@@ -70,93 +66,102 @@
 #' PNAS, 1981, 78:3824-3828 (T.P.Hopp & K.R.Woods). (The hydrophilicity data)
 #'
 #' @examples
-#' x = readFASTA(system.file("protseq/P00750.fasta", package = "protr"))[[1]]
+#' x <- readFASTA(system.file("protseq/P00750.fasta", package = "protr"))[[1]]
 #' extractAPAAC(x)
 #'
-#' myprops = data.frame(
+#' myprops <- data.frame(
 #'   AccNo = c("MyProp1", "MyProp2", "MyProp3"),
-#'   A = c(0.62,  -0.5, 15),  R = c(-2.53,   3, 101),
-#'   N = c(-0.78,  0.2, 58),  D = c(-0.9,    3, 59),
-#'   C = c(0.29,    -1, 47),  E = c(-0.74,   3, 73),
-#'   Q = c(-0.85,  0.2, 72),  G = c(0.48,    0, 1),
-#'   H = c(-0.4,  -0.5, 82),  I = c(1.38, -1.8, 57),
-#'   L = c(1.06,  -1.8, 57),  K = c(-1.5,    3, 73),
-#'   M = c(0.64,  -1.3, 75),  F = c(1.19, -2.5, 91),
-#'   P = c(0.12,     0, 42),  S = c(-0.18, 0.3, 31),
-#'   T = c(-0.05, -0.4, 45),  W = c(0.81, -3.4, 130),
-#'   Y = c(0.26,  -2.3, 107), V = c(1.08, -1.5, 43))
+#'   A = c(0.62, -0.5, 15), R = c(-2.53, 3, 101),
+#'   N = c(-0.78, 0.2, 58), D = c(-0.9, 3, 59),
+#'   C = c(0.29, -1, 47), E = c(-0.74, 3, 73),
+#'   Q = c(-0.85, 0.2, 72), G = c(0.48, 0, 1),
+#'   H = c(-0.4, -0.5, 82), I = c(1.38, -1.8, 57),
+#'   L = c(1.06, -1.8, 57), K = c(-1.5, 3, 73),
+#'   M = c(0.64, -1.3, 75), F = c(1.19, -2.5, 91),
+#'   P = c(0.12, 0, 42), S = c(-0.18, 0.3, 31),
+#'   T = c(-0.05, -0.4, 45), W = c(0.81, -3.4, 130),
+#'   Y = c(0.26, -2.3, 107), V = c(1.08, -1.5, 43)
+#' )
 #'
 #' # use 2 default properties, 4 properties from the
 #' # AAindex database, and 3 cutomized properties
 #' extractAPAAC(
-#'   x, customprops = myprops,
+#'   x,
+#'   customprops = myprops,
 #'   props = c(
 #'     "Hydrophobicity", "Hydrophilicity",
 #'     "CIDH920105", "BHAR880101",
 #'     "CHAM820101", "CHAM820102",
-#'     "MyProp1", "MyProp2", "MyProp3")
+#'     "MyProp1", "MyProp2", "MyProp3"
+#'   )
 #' )
-
-extractAPAAC = function(
-  x, props = c('Hydrophobicity', 'Hydrophilicity'),
+extractAPAAC <- function(
+  x, props = c("Hydrophobicity", "Hydrophilicity"),
   lambda = 30, w = 0.05, customprops = NULL) {
+  if (protcheck(x) == FALSE) {
+    stop("x has unrecognized amino acid type")
+  }
 
-  if (protcheck(x) == FALSE)
-    stop('x has unrecognized amino acid type')
-
-  if (nchar(x) <= lambda)
+  if (nchar(x) <= lambda) {
     stop('Length of the protein sequence must be greater than "lambda"')
+  }
 
-  AAidx = read.csv(system.file(
-    'sysdata/AAidx.csv', package = 'protr'), header = TRUE)
+  AAidx <- read.csv(system.file(
+    "sysdata/AAidx.csv",
+    package = "protr"
+  ), header = TRUE)
 
-  tmp = data.frame(
+  tmp <- data.frame(
     AccNo = c("Hydrophobicity", "Hydrophilicity", "SideChainMass"),
-    A = c(0.62,  -0.5, 15),  R = c(-2.53,   3, 101),
-    N = c(-0.78,  0.2, 58),  D = c(-0.9,    3, 59),
-    C = c(0.29,    -1, 47),  E = c(-0.74,   3, 73),
-    Q = c(-0.85,  0.2, 72),  G = c(0.48,    0, 1),
-    H = c(-0.4,  -0.5, 82),  I = c(1.38, -1.8, 57),
-    L = c(1.06,  -1.8, 57),  K = c(-1.5,    3, 73),
-    M = c(0.64,  -1.3, 75),  F = c(1.19, -2.5, 91),
-    P = c(0.12,     0, 42),  S = c(-0.18, 0.3, 31),
-    T = c(-0.05, -0.4, 45),  W = c(0.81, -3.4, 130),
-    Y = c(0.26,  -2.3, 107), V = c(1.08, -1.5, 43))
+    A = c(0.62, -0.5, 15), R = c(-2.53, 3, 101),
+    N = c(-0.78, 0.2, 58), D = c(-0.9, 3, 59),
+    C = c(0.29, -1, 47), E = c(-0.74, 3, 73),
+    Q = c(-0.85, 0.2, 72), G = c(0.48, 0, 1),
+    H = c(-0.4, -0.5, 82), I = c(1.38, -1.8, 57),
+    L = c(1.06, -1.8, 57), K = c(-1.5, 3, 73),
+    M = c(0.64, -1.3, 75), F = c(1.19, -2.5, 91),
+    P = c(0.12, 0, 42), S = c(-0.18, 0.3, 31),
+    T = c(-0.05, -0.4, 45), W = c(0.81, -3.4, 130),
+    Y = c(0.26, -2.3, 107), V = c(1.08, -1.5, 43)
+  )
 
-  AAidx = rbind(AAidx, tmp)
+  AAidx <- rbind(AAidx, tmp)
 
-  if (!is.null(customprops)) AAidx = rbind(AAidx, customprops)
+  if (!is.null(customprops)) AAidx <- rbind(AAidx, customprops)
 
-  aaidx = AAidx[, -1]
-  row.names(aaidx) = AAidx[, 1]
+  aaidx <- AAidx[, -1]
+  row.names(aaidx) <- AAidx[, 1]
 
-  n = length(props)
+  n <- length(props)
 
   # Standardize H0 to H
 
-  H0 = as.matrix(aaidx[props, ])
+  H0 <- as.matrix(aaidx[props, ])
 
-  H  = matrix(ncol = 20, nrow = n)
-  for (i in 1:n) H[i, ] =
-    (H0[i, ] - mean(H0[i, ]))/(sqrt(sum((H0[i, ] - mean(H0[i, ]))^2)/20))
-  AADict = c(
-    'A', 'R', 'N', 'D', 'C', 'E', 'Q', 'G', 'H', 'I',
-    'L', 'K', 'M', 'F', 'P', 'S', 'T', 'W', 'Y', 'V')
-  dimnames(H) = list(props, AADict)
+  H <- matrix(ncol = 20, nrow = n)
+  for (i in 1:n) {
+    H[i, ] <-
+      (H0[i, ] - mean(H0[i, ])) / (sqrt(sum((H0[i, ] - mean(H0[i, ]))^2) / 20))
+  }
+  AADict <- c(
+    "A", "R", "N", "D", "C", "E", "Q", "G", "H", "I",
+    "L", "K", "M", "F", "P", "S", "T", "W", "Y", "V"
+  )
+  dimnames(H) <- list(props, AADict)
 
   # Compute H^{1,2, ..., n}_{i, j}
 
-  Theta = vector('list', lambda)
-  for (i in 1:lambda) Theta[[i]] = vector('list', n)
+  Theta <- vector("list", lambda)
+  for (i in 1:lambda) Theta[[i]] <- vector("list", n)
 
-  xSplitted = strsplit(x, split = '')[[1]]
+  xSplitted <- strsplit(x, split = "")[[1]]
 
-  N = length(xSplitted)
+  N <- length(xSplitted)
 
   for (i in 1:lambda) {
     for (j in 1:n) {
-      for (k in 1:(N-i)) {
-        Theta[[i]][[j]][k] =
+      for (k in 1:(N - i)) {
+        Theta[[i]][[j]][k] <-
           H[props[j], xSplitted[k]] * H[props[j], xSplitted[k + i]]
       }
     }
@@ -164,25 +169,25 @@ extractAPAAC = function(
 
   # Compute tau
 
-  tau = sapply(unlist(Theta, recursive = FALSE), mean)
+  tau <- sapply(unlist(Theta, recursive = FALSE), mean)
 
   # Compute first 20 features
 
-  fc  = summary(factor(xSplitted, levels = AADict), maxsum = 21)
-  Pc1 = fc/(1 + (w * sum(tau)))
-  names(Pc1) = paste('Pc1.', names(Pc1), sep = '')
+  fc <- summary(factor(xSplitted, levels = AADict), maxsum = 21)
+  Pc1 <- fc / (1 + (w * sum(tau)))
+  names(Pc1) <- paste("Pc1.", names(Pc1), sep = "")
 
   # Compute last n * lambda features
 
-  Pc2 = (w * tau)/(1 + (w * sum(tau)))
-  names(Pc2) = paste(
-    'Pc2', as.vector(outer(props, 1:lambda, paste, sep = '.')),
-    sep = '.')
+  Pc2 <- (w * tau) / (1 + (w * sum(tau)))
+  names(Pc2) <- paste(
+    "Pc2", as.vector(outer(props, 1:lambda, paste, sep = ".")),
+    sep = "."
+  )
 
   # Combine 20 + (n * lambda) features
 
-  Pc = c(Pc1, Pc2)
+  Pc <- c(Pc1, Pc2)
 
   Pc
-
 }
